==> AusweisApp2-1.22.2.tar.gz: AusweisApp2-1.22.2/src/global/LanguageLoader.h <==
/*
 * \brief Loads translation files for different languages.
 *
 * \copyright Copyright (c) 2014-2021 Governikus GmbH & Co. KG, Germany
 */

#pragma once

#include <QLocale>
#include <QPointer>
#include <QSharedPointer>
#include <QTranslator>
#include <QVector>

class test_LanguageLoader;
class test_ProviderParser;
class test_ProviderConfigurationParser;

namespace governikus
{

class LanguageLoader
{
	private:
		friend class ::test_LanguageLoader;
		friend class ::test_ProviderConfigurationParser;
		static const QLocale::Language mFallbackLanguage;
		static QLocale mDefaultLanguage;

		QString mPath;
		QVector<QSharedPointer<QTranslator>> mTranslatorList;
		const QStringList mComponentList;
		QLocale mUsedLocale;

		Q_DISABLE_COPY(LanguageLoader)

		bool loadTranslationFiles(const QLocale& pLocale);
		QSharedPointer<QTranslator> createTranslator(const QLocale& pLocale, const QString& pComponent);

	protected:
		LanguageLoader();
		~LanguageLoader();

	public:
		static const QLocale& getDefaultLanguage();
		static void setDefaultLanguage(const QLocale& pLocale);
		static LanguageLoader& getInstance();
		static QString getLocalCode(const QLocale& pLocale = getInstance().getUsedLocale());

#ifndef QT_NO_DEBUG
		[[nodiscard]] const QString& getPath() const;
		void setPath(const QString& pPath);
#endif

		void load(const QLocale& pLocale = getDefaultLanguage());
		void unload();
		[[nodiscard]] bool isLoaded() const;
		[[nodiscard]] const QLocale& getUsedLocale() const;
		[[nodiscard]] QLocale::Language getFallbackLanguage() const;
		[[nodiscard]] QList<QLocale> getAvailableLocales() const;
};

} // namespace governikus

==> AusweisApp-2.4.0.tar.gz: AusweisApp-2.4.0/src/global/LanguageLoader.h <==
/**
 * Copyright (c) 2014-2025 Governikus GmbH & Co. KG, Germany
 */

#pragma once

#include <QList>
#include <QLocale>
#include <QSharedPointer>
#include <QTranslator>


class test_LanguageLoader;
class test_ProviderParser;
class test_ProviderConfigurationParser;


namespace governikus
{

class LanguageLoader
{
	Q_DISABLE_COPY(LanguageLoader)
	friend class ::test_LanguageLoader;
	friend class ::test_ProviderConfigurationParser;

	private:
		static const QLocale::Language mFallbackLanguage;
		static QLocale mDefaultLanguage;

		QString mPath;
		QList<QSharedPointer<QTranslator>> mTranslatorList;
		const QStringList mComponentList;
		QLocale mUsedLocale;

		bool loadTranslationFiles(const QLocale& pLocale);
		QSharedPointer<QTranslator> createTranslator(const QLocale& pLocale, const QString& pComponent);
		[[nodiscard]] static const QLocale& getDefaultLanguage();

	protected:
		LanguageLoader();
		~LanguageLoader() = default;

	public:
		static LanguageLoader& getInstance();
		static QString getLocaleCode(const QLocale& pLocale = getInstance().getUsedLocale());

#ifndef QT_NO_DEBUG
		[[nodiscard]] const QString& getPath() const;
		void setPath(const QString& pPath);
#endif

		void load(const QLocale& pLocale = getDefaultLanguage());
		void unload();
		[[nodiscard]] bool isLoaded() const;
		[[nodiscard]] const QLocale& getUsedLocale() const;
		[[nodiscard]] QLocale::Language getFallbackLanguage() const;
		[[nodiscard]] QList<QLocale> getAvailableLocales() const;
};

} // namespace governikus
